AnyVar
!!!!!!

AnyVar enables **registration**, **lookup**, and **search** of genetic variants, as a standalone service or an individual node within a distributed genomic resource network. Its goals are to:

* Provide an open source, off-the-shelf solution that lowers the technical barriers for genomic data resources to comprehensively describe and search genomic variants
* Support a broad range of query modes, including VRS ID lookups, HGVS expressions, gene-based searches, and genomic ranges
* Translate community nomenclatures and conventions into a universal model for variant representation
* Provide a community-driven, extensible platform for shared conventions and policy to realize the above goals

If you're setting up AnyVar for the first time, begin with the :doc:`Getting Started guide <getting_started/index>`, which covers different installation options. To learn how to use AnyVar programmatically or as a service, see the :doc:`Usage section <usage/index>`. For further assistance, please refer to :doc:`Getting Help <help>`.

.. toctree::
   :maxdepth: 2
   :caption: Contents
   :hidden:

   Getting Started<getting_started/index>
   Features<features>
   Usage<usage/index>
   Configuration<configuration/index>
   API Reference<api/index>
   Getting Help<help>
   Changelog<changelog>
   Contributing<contributing>
   License<license>
